Index: abi/include/_bits/uchar.h
===================================================================
--- abi/include/_bits/uchar.h	(revision ce52c333dd9013cd4e9c22121ab41c36aee9c7d4)
+++ abi/include/_bits/uchar.h	(revision ce52c333dd9013cd4e9c22121ab41c36aee9c7d4)
@@ -0,0 +1,46 @@
+/*
+ * Copyright (c) 2020 Martin Decky
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * - Redistributions of source code must retain the above copyright
+ *   notice, this list of conditions and the following disclaimer.
+ * - Redistributions in binary form must reproduce the above copyright
+ *   notice, this list of conditions and the following disclaimer in the
+ *   documentation and/or other materials provided with the distribution.
+ * - The name of the author may not be used to endorse or promote products
+ *   derived from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+/** @addtogroup bits
+ * @{
+ */
+/** @file
+ */
+
+#ifndef _BITS_UCHAR_H_
+#define _BITS_UCHAR_H_
+
+#include <stdint.h>
+
+typedef uint8_t char8_t;
+typedef uint32_t char32_t;
+
+#endif
+
+/** @}
+ */
Index: abi/include/inttypes.h
===================================================================
--- abi/include/inttypes.h	(revision a6302aeae3f6b03e65410b4c2b6091d819fe88d5)
+++ abi/include/inttypes.h	(revision ce52c333dd9013cd4e9c22121ab41c36aee9c7d4)
@@ -43,4 +43,5 @@
 #include <stdint.h>
 #include <_bits/wchar_t.h>
+#include <_bits/uchar.h>
 #include <_bits/decls.h>
 
@@ -337,10 +338,12 @@
 } imaxdiv_t;
 
-intmax_t imaxabs(intmax_t);
-imaxdiv_t imaxdiv(intmax_t, intmax_t);
-intmax_t strtoimax(const char *__restrict__, char **__restrict__, int);
-uintmax_t strtoumax(const char *__restrict__, char **__restrict__, int);
-intmax_t wcstoimax(const wchar_t *__restrict__, wchar_t **__restrict__, int);
-uintmax_t wcstoumax(const wchar_t *__restrict__, wchar_t **__restrict__, int);
+extern intmax_t imaxabs(intmax_t);
+extern imaxdiv_t imaxdiv(intmax_t, intmax_t);
+extern intmax_t strtoimax(const char *__restrict__, char **__restrict__, int);
+extern uintmax_t strtoumax(const char *__restrict__, char **__restrict__, int);
+extern intmax_t wcstoimax(const wchar_t *__restrict__, wchar_t **__restrict__,
+    int);
+extern uintmax_t wcstoumax(const wchar_t *__restrict__, wchar_t **__restrict__,
+    int);
 
 __C_DECLS_END;

Index: abi/include/_bits/wchar_limits.h
===================================================================
--- abi/include/_bits/wchar_limits.h	(revision a6302aeae3f6b03e65410b4c2b6091d819fe88d5)
+++ abi/include/_bits/wchar_limits.h	(revision ce52c333dd9013cd4e9c22121ab41c36aee9c7d4)
@@ -38,14 +38,14 @@
  */
 
-#ifndef _BITS_WCHAR_MIN_H_
-#define _BITS_WCHAR_MIN_H_
+#ifndef _BITS_WCHAR_LIMITS_H_
+#define _BITS_WCHAR_LIMITS_H_
 
 /* wchar_t should always be signed int in HelenOS. */
 
 #include <_bits/wchar_t.h>
 
 #ifndef __cplusplus
-_Static_assert(((wchar_t)-1) < 0, "wchar_t is not int");
-_Static_assert(sizeof(wchar_t) == 4, "wchar_t is not int");
+_Static_assert(((wchar_t) -1) < 0, "wchar_t is not int32_t");
+_Static_assert(sizeof(wchar_t) == 4, "wchar_t is not int32_t");
 #endif
 
@@ -38,14 +38,14 @@
 
-/* wchar_t should always be signed int in HelenOS. */
+/* wchar_t should always be int32_t in HelenOS. */
 
 #include <_bits/wchar_t.h>